FD.theorcontours: Contour Lines of a Flexible Dirichlet
Description
Contour lines of a Flexible Dirichlet with given parameters on the ternary diagram or on the right triangle.
Usage
FD.theorcontours(a, p, t, type = "ternary", var = c(1, 2), zoomed = T,
showgrid = T, nlevels = 10)
Arguments
a
vector of the non-negative alpha parameters.
p
vector of the clusters' probabilities. It must sum to one.
t
non-negative scalar tau parameter.
type
string indicating whether to plot the contour lines on a ternary diagram 'ternary', or on a right triangle plot 'right'.
var
numeric vector containing the two variables to be plotted on the axis. Used only if type='right'.
zoomed
if TRUE, shows only the area where most of the density is concentrated. If FALSE, shows the whole area.
showgrid
if TRUE, shows the axis and the labels. If FALSE, only the graph is printed.
nlevels
approximate number of contour lines to be drawn.
Details
The number of variables in the Flexible Dirichlet must be 3 to draw a plot. Vectors a and p must be of the same length.
References
Ongaro, A. and Migliorati, S. (2013) A generalization of the Dirichlet distribution. Journal of Multivariate Analysis, 114, 412--426. Migliorati, S., Ongaro, A. and Monti, G. S. (2016) A structured Dirichlet mixture model for compositional data: inferential and applicative issues. Statistics and Computing, doi:10.1007/s11222-016-9665-y.